@@ -3,7 +3,7 @@ from Fortuna import TruffleShuffle, d, dice
 from MonsterGen.spells import random_spell
 
 
-__all__ = ("monster_loot", "horde_loot")
+__all__ = ("monster_loot", "horde_loot", "random_loot")
 
 
 class Loot:
